{
    "version": "0.2.0",
    "configurations": [
        {
            "name": "Python: Server",
            "type": "python",
            "request": "launch",
            "module": "{{ project }}",
            "args": ["run"],
            "env": {
                "{{ project|upper }}_SETTINGS": "${workspaceFolder}/{{ project }}.cfg"
            }
        },
        {
            "name": "Python: MQ",
            "type": "python",
            "request": "launch",
            "module": "{{ project }}",
            "args": ["mq"],
            "env": {
                "{{ project|upper }}_SETTINGS": "${workspaceFolder}/{{ project }}.cfg"
            }
        }
    ]
}